@@ -8,7 +8,7 @@ from .sshfs import SSHFS
 
 __license__ = "LGPL-2.1+"
 __copyright__ = "Copyright (c) 2017-2019 Martin Larralde"
-__author__ = "Martin Larralde <martin.larralde@ens-cachan.fr>"
+__author__ = "Martin Larralde <martin.larralde@ens-paris-saclay.fr>"
 __version__ = 'dev'
 
 # Dynamically get the version of the installed module
